@@ -115,7 +115,7 @@ class Kraken_html:
         return page_content
 
 
-    def get_record_page(self, record_type, record_id, breadcrumbs = ''):
+    def get_record_page(self, record, breadcrumbs = ''):
         # Returns full web page with relevant web part for the record
         '''
         Page structure:
@@ -127,7 +127,6 @@ class Kraken_html:
 
         '''
 
-        record = self.get_db_record(record_type, record_id)
 
         kr = KR_HTML(record)
 
